@@ -19,29 +19,36 @@ class BaseError(Exception):
 
 class FileNotExistError(BaseError):
     """Image does not exist."""
-    pass
 
 
 class TemplateInputError(BaseError):
     """Resolution input is not right."""
-    pass
 
 
 class NoSIFTModuleError(BaseError):
     """Resolution input is not right."""
-    pass
 
 
 class NoSiftMatchPointError(BaseError):
     """Exception raised for errors 0 sift points found in the input images."""
-    pass
 
 
 class SiftResultCheckError(BaseError):
     """Exception raised for errors 0 sift points found in the input images."""
-    pass
 
 
 class HomographyError(BaseError):
     """In homography, find no mask, should kill points which is duplicate."""
-    pass
+
+
+class NoModuleError(BaseError):
+    """Resolution input is not right."""
+
+
+class NoMatchPointError(BaseError):
+    """Exception raised for errors 0 keypoint found in the input images."""
+
+
+class MatchResultCheckError(BaseError):
+    """Exception raised for errors 0 keypoint found in the input images."""
+
