@@ -535,7 +535,7 @@ class ADB(object):
         if local in self._forward_local_using:
             self._forward_local_using.remove(local)
 
-    def install_app(self, filepath, replace=False):
+    def install_app(self, filepath, replace=False, install_options=None):
         """
         Perform `adb install` command
 
@@ -543,6 +543,13 @@ class ADB(object):
             filepath: full path to file to be installed on the device
             replace: force to replace existing application, default is False
 
+                e.g.["-t",  # allow test packages
+                    "-l",  # forward lock application,
+                    "-s",  # install application on sdcard,
+                    "-d",  # allow version code downgrade (debuggable packages only)
+                    "-g",  # grant all runtime permissions
+                ]
+
         Returns:
             command output
 
@@ -553,10 +560,11 @@ class ADB(object):
         if not os.path.isfile(filepath):
             raise RuntimeError("file: %s does not exists" % (repr(filepath)))
 
-        if not replace:
-            cmds = ["install", filepath]
-        else:
-            cmds = ["install", "-r", filepath]
+        if not install_options or type(install_options) != list:
+            install_options = []
+        if replace:
+            install_options.append("-r")
+        cmds = ["install", ] + install_options + [filepath, ]
         out = self.cmd(cmds)
 
         if re.search(r"Failure \[.*?\]", out):
@@ -565,13 +573,21 @@ class ADB(object):
 
         return out
 
-    def install_multiple_app(self, filepath, replace=False):
+    def install_multiple_app(self, filepath, replace=False, install_options=None):
         """
             Perform `adb install-multiple` command
 
             Args:
                 filepath: full path to file to be installed on the device
                 replace: force to replace existing application, default is False
+                install_options:  list of options
+                    e.g.["-t",  # allow test packages
+                        "-l",  # forward lock application,
+                        "-s",  # install application on sdcard,
+                        "-d",  # allow version code downgrade (debuggable packages only)
+                        "-g",  # grant all runtime permissions
+                        "-p",  # partial application install (install-multiple only)
+                    ]
 
             Returns:
                 command output
@@ -582,19 +598,19 @@ class ADB(object):
         if not os.path.isfile(filepath):
             raise RuntimeError("file: %s does not exists" % (repr(filepath)))
 
-        if not replace:
-            cmds = ["install-multiple", filepath]
-        else:
-            cmds = ["install-multiple", "-r", filepath]
+        if not install_options or type(install_options) != list:
+            install_options = []
+        if replace:
+            install_options.append("-r")
+        cmds = ["install-multiple", ] + install_options + [filepath, ]
 
         try:
             out = self.cmd(cmds)
         except AdbError as err:
-            if "UNSUPPORTED" in err.stderr or "Failed to create session" in err.stderr:
-                return self.install_app(filepath, replace)
-            elif "Failed to finalize session" in err.stderr:
+            if "Failed to finalize session".lower() in err.stderr.lower():
                 return "Success"
-            raise err
+            else:
+                return self.install_app(filepath, replace)
 
         if re.search(r"Failure \[.*?\]", out):
             print(out)
@@ -943,6 +959,8 @@ class ADB(object):
                 displayInfo[prop] = float(m.group(prop))
             return displayInfo
 
+        return {}
+
     def _getDisplayDensity(self, key, strip=True):
         """
         Get display density
@@ -1004,9 +1022,10 @@ class ADB(object):
         """
         dat = self.shell('dumpsys activity top')
         activityRE = re.compile('\s*ACTIVITY ([A-Za-z0-9_.]+)/([A-Za-z0-9_.]+) \w+ pid=(\d+)')
-        m = activityRE.search(dat)
+        # in Android8.0 or higher, the result may be more than one
+        m = activityRE.findall(dat)
         if m:
-            return (m.group(1), m.group(2), m.group(3))
+            return m[-1]
         else:
             raise AirtestError("Can not get top activity, output:%s" % dat)
 
@@ -1050,11 +1069,8 @@ class ADB(object):
         Returns:
             True or False whether the screen is locked or not
 
-        Notes:
-            Does not work on Xiaomi 2S
-
         """
-        lockScreenRE = re.compile('mShowingLockscreen=(true|false)')
+        lockScreenRE = re.compile('(?:mShowingLockscreen|isStatusBarKeyguard)=(true|false)')
         m = lockScreenRE.search(self.shell('dumpsys window policy'))
         if not m:
             raise AirtestError("Couldn't determine screen lock state")
@@ -1202,7 +1218,7 @@ class ADB(object):
         if not re.search(r"Status:\s*ok", out):
             raise AirtestError("Starting App: %s/%s Failed!" % (package, activity))
 
-        matcher = re.search(r"TotalTime:\s*(\d+)", out)
+        matcher = re.search(r"ThisTime:\s*(\d+)", out)
         if matcher:
             return int(matcher.group(1))
         else:
@@ -1381,6 +1397,10 @@ class ADB(object):
         res = str(num) + 'GHz'
         return res.strip()
 
+    def get_cpuabi(self):
+        res = self.shell("getprop ro.product.cpu.abi")
+        return res.strip()
+
     def get_gpu(self):
         res = self.shell("dumpsys SurfaceFlinger")
         pat = re.compile(r'GLES:\s+(.*)')
@@ -1420,6 +1440,7 @@ class ADB(object):
             "display": self.getPhysicalDisplayInfo,
             "cpuinfo": self.get_cpuinfo,
             "cpufreq": self.get_cpufreq,
+            "cpuabi": self.get_cpuabi,
             "sdkversion": self.sdk_version,
             "gpu": self.get_gpu,
             "model": self.get_model,
