@@ -189,10 +189,9 @@ class Minitouch(object):
         time.sleep(duration)
         self.handle("u 0\nc\n")
 
-    @on_method_ready('install_and_setup')
-    def swipe(self, tuple_from_xy, tuple_to_xy, duration=0.8, steps=5):
+    def __swipe_move(self, tuple_from_xy, tuple_to_xy, duration=0.8, steps=5):
         """
-        Perform swipe event
+        Return a sequence of swipe motion events (only MoveEvent)
 
         minitouch protocol example::
 
@@ -218,28 +217,65 @@ class Minitouch(object):
             steps: size of swipe step, default is 5
 
         Returns:
-            None
+            [MoveEvent(from_x, from_y), ..., MoveEvent(to_x, to_y)]
 
         """
         from_x, from_y = tuple_from_xy
         to_x, to_y = tuple_to_xy
 
-        from_x, from_y = self.__transform_xy(from_x, from_y)
-        to_x, to_y = self.__transform_xy(to_x, to_y)
-
+        ret = []
         interval = float(duration) / (steps + 1)
-        self.handle("d 0 {:.0f} {:.0f} 50\nc\n".format(from_x, from_y))
-        time.sleep(interval)
+
         for i in range(1, steps):
-            self.handle("m 0 {:.0f} {:.0f} 50\nc\n".format(
-                from_x + (to_x - from_x) * i / steps,
-                from_y + (to_y - from_y) * i / steps,
-            ))
-            time.sleep(interval)
-        for i in range(10):
-            self.handle("m 0 {:.0f} {:.0f} 50\nc\n".format(to_x, to_y))
-        time.sleep(interval)
-        self.handle("u 0\nc\n")
+            ret.append(MoveEvent((from_x + (to_x - from_x) * i / steps,
+                                  from_y + (to_y - from_y) * i / steps)))
+            ret.append(SleepEvent(interval))
+        ret += [MoveEvent((to_x, to_y)), SleepEvent(interval)]
+        return ret
+
+    @on_method_ready('install_and_setup')
+    def swipe_along(self, coordinates_list, duration=0.8, steps=5):
+        """
+        Perform swipe event across multiple points in sequence.
+
+        Args:
+            coordinates_list: list of coordinates: [(x1, y1), (x2, y2), (x3, y3)]
+            duration: time interval for swipe duration, default is 0.8
+            steps: size of swipe step, default is 5
+
+        Returns:
+            None
+
+        """
+        tuple_from_xy = coordinates_list[0]
+        swipe_events = [DownEvent(tuple_from_xy), SleepEvent(0.1)]
+        for tuple_to_xy in coordinates_list[1:]:
+            swipe_events += self.__swipe_move(tuple_from_xy, tuple_to_xy, duration=duration, steps=steps)
+            tuple_from_xy = tuple_to_xy
+
+        swipe_events.append(UpEvent())
+        self.perform(swipe_events)
+
+    @on_method_ready('install_and_setup')
+    def swipe(self, tuple_from_xy, tuple_to_xy, duration=0.8, steps=5):
+      
+        """
+        Perform swipe event.
+
+        Args:
+            tuple_from_xy: start point
+            tuple_to_xy: end point
+            duration: time interval for swipe duration, default is 0.8
+            steps: size of swipe step, default is 5
+
+        Returns:
+            None
+
+        """
+        swipe_events = [DownEvent(tuple_from_xy), SleepEvent(0.1)]
+        swipe_events += self.__swipe_move(tuple_from_xy, tuple_to_xy, duration=duration, steps=steps)
+        swipe_events.append(UpEvent())
+        self.perform(swipe_events)
 
     @on_method_ready('install_and_setup')
     def two_finger_swipe(self, tuple_from_xy, tuple_to_xy, duration=0.8, steps=5):
@@ -346,6 +382,11 @@ class Minitouch(object):
 
         x1, y1 = x0 - w * percent / 2, y0 - h * percent / 2
         x2, y2 = x0 + w * percent / 2, y0 + h * percent / 2
+        # 对计算出的原始坐标进行实际滑动位置的转换
+        x0, y0 = self.__transform_xy(x0, y0)
+        x1, y1 = self.__transform_xy(x1, y1)
+        x2, y2 = self.__transform_xy(x2, y2)
+
         cmds = []
         if in_or_out == 'in':
             cmds.append("d 0 {:.0f} {:.0f} 50\nd 1 {:.0f} {:.0f} 50\nc\n".format(x1, y1, x2, y2))
