@@ -9,9 +9,10 @@ from six.moves.urllib.parse import parse_qsl, urlparse
 
 from airtest.core.cv import Template, loop_find, try_log_screen
 from airtest.core.error import TargetNotFoundError
+from airtest.core.settings import Settings as ST
+from airtest.utils.compat import script_log_dir
 from airtest.core.helper import (G, delay_after_operation, import_device_cls,
                                  logwrap, set_logdir, using, log)
-from airtest.core.settings import Settings as ST
 
 
 """
@@ -96,21 +97,22 @@ def set_current(idx):
 def auto_setup(basedir=None, devices=None, logdir=None, project_root=None):
     """
     Auto setup running env and try connect android device if not device connected.
+
+    :param basedir: basedir of script, __file__ is also acceptable.
+    :param devices: connect_device uri in list.
+    :param logdir: log dir for script report, default is None for no log, set to `True` for <basedir>/log.
+    :param project_root: project root dir for `using` api.
     """
-    if devices:
-        for dev in devices:
-            connect_device(dev)
-    elif not G.DEVICE_LIST:
-        try:
-            connect_device("Android:///")
-        except IndexError:
-            pass
     if basedir:
         if os.path.isfile(basedir):
             basedir = os.path.dirname(basedir)
         if basedir not in G.BASEDIR:
             G.BASEDIR.append(basedir)
+    if devices:
+        for dev in devices:
+            connect_device(dev)
     if logdir:
+        logdir = script_log_dir(basedir, logdir)
         set_logdir(logdir)
     if project_root:
         ST.PROJECT_ROOT = project_root
@@ -171,15 +173,16 @@ def clear_app(package):
 
 
 @logwrap
-def install(filepath):
+def install(filepath, **kwargs):
     """
     Install application on device
 
     :param filepath: the path to file to be installed on target device
+    :param kwargs: platform specific `kwargs`, please refer to corresponding docs
     :return: None
     :platforms: Android, iOS
     """
-    return G.DEVICE.install_app(filepath)
+    return G.DEVICE.install_app(filepath, **kwargs)
 
 
 @logwrap
@@ -205,16 +208,14 @@ def snapshot(filename=None, msg=""):
     :return: absolute path of the screenshot
     :platforms: Android, iOS, Windows
     """
-    if not filename:
-        filename = "%(time)d.jpg" % {'time': time.time() * 1000}
-    if not os.path.isabs(filename):
-        logdir = ST.LOG_DIR or "."
-        filepath = os.path.join(logdir, filename)
+    if filename:
+        if not os.path.isabs(filename):
+            logdir = ST.LOG_DIR or "."
+            filename = os.path.join(logdir, filename)
+        screen = G.DEVICE.snapshot(filename)
+        return try_log_screen(screen)
     else:
-        filepath = filename
-    screen = G.DEVICE.snapshot(filepath)
-    try_log_screen(screen)
-    return filepath
+        return try_log_screen()
 
 
 @logwrap
@@ -354,7 +355,7 @@ def keyevent(keyname, **kwargs):
 
 
 @logwrap
-def text(text, enter=True):
+def text(text, enter=True, **kwargs):
     """
     Input text on the target device. Text input widget must be active first.
 
@@ -363,7 +364,7 @@ def text(text, enter=True):
     :return: None
     :platforms: Android, Windows, iOS
     """
-    G.DEVICE.text(text, enter=enter)
+    G.DEVICE.text(text, enter=enter, **kwargs)
     delay_after_operation()
 
 
