@@ -3,15 +3,17 @@
 import json
 import os
 import io
+import re
 import six
 import sys
 import shutil
 import jinja2
 import traceback
 from copy import deepcopy
+from jinja2 import evalcontextfilter, Markup, escape
 from airtest.aircv import imread, get_resolution
+from airtest.utils.compat import decode_path, script_dir_name
 from airtest.cli.info import get_script_info
-from airtest.utils.compat import decode_path
 from six import PY3
 from pprint import pprint
 
@@ -22,13 +24,24 @@ HTML_FILE = "log.html"
 STATIC_DIR = os.path.dirname(__file__)
 
 
+_paragraph_re = re.compile(r'(?:\r\n|\r|\n){2,}')
+
+@evalcontextfilter
+def nl2br(eval_ctx, value):
+    result = u'\n\n'.join(u'<p>%s</p>' % p.replace('\n', '<br>\n')
+                          for p in _paragraph_re.split(escape(value)))
+    if eval_ctx.autoescape:
+        result = Markup(result)
+    return result
+
 class LogToHtml(object):
     """Convert log to html display """
     scale = 0.5
 
-    def __init__(self, script_root, log_root="", static_root="", export_dir=None, logfile=LOGFILE, lang="en", plugins=None):
+    def __init__(self, script_root, log_root="", static_root="", export_dir=None, script_name="", logfile=LOGFILE, lang="en", plugins=None):
         self.log = []
         self.script_root = script_root
+        self.script_name = script_name
         self.log_root = log_root
         self.static_root = static_root or STATIC_DIR
         self.test_result = True
@@ -191,9 +204,9 @@ class LogToHtml(object):
                     if not os.path.isfile(os.path.join(self.script_root, image_path)):
                         shutil.copy(value['_filepath'], self.script_root)  # copy image used by using statement
                 else:
-                    image_path = os.path.abspath(value['_filepath'])
+                    image_path = os.path.abspath(value['_filepath'] or value['filename'])
                 arg["image"] = image_path
-                crop_img = imread(value['_filepath'])
+                crop_img = imread(value['_filepath'] or value['filename'])
                 arg["resolution"] = get_resolution(crop_img)
         return code
 
@@ -277,6 +290,7 @@ class LogToHtml(object):
             extensions=(),
             autoescape=True
         )
+        env.filters['nl2br'] = nl2br
         template = env.get_template(template_name)
         html = template.render(**template_vars)
 
@@ -290,9 +304,9 @@ class LogToHtml(object):
     def is_pos(self, v):
         return isinstance(v, (list, tuple))
 
-    def copy_tree(self, src, dst):
+    def copy_tree(self, src, dst, ignore=None):
         try:
-            shutil.copytree(src, dst)
+            shutil.copytree(src, dst, ignore=ignore)
         except Exception as e:
             print(e)
 
@@ -310,26 +324,31 @@ class LogToHtml(object):
         if os.path.normpath(logpath) != os.path.normpath(self.log_root):
             if os.path.isdir(logpath):
                 shutil.rmtree(logpath, ignore_errors=True)
-            self.copy_tree(self.log_root, logpath)
-        # copy static files
-        for subdir in ["css", "fonts", "image", "js"]:
-            self.copy_tree(os.path.join(STATIC_DIR, subdir), os.path.join(dirpath, "static", subdir))
+            self.copy_tree(self.log_root, logpath, ignore=shutil.ignore_patterns(dirname))
+        # if self.static_root is not a http server address, copy static files from local directory
+        if not self.static_root.startswith("http"):
+            for subdir in ["css", "fonts", "image", "js"]:
+                self.copy_tree(os.path.join(self.static_root, subdir), os.path.join(dirpath, "static", subdir))
 
         return dirpath, logpath
 
     def report(self, template_name, output_file=None, record_list=None):
         self._load()
         steps = self._analyse()
-        info = json.loads(get_script_info(self.script_root))
+
+        script_path = os.path.join(self.script_root, self.script_name)
+        info = json.loads(get_script_info(script_path))
 
         if self.export_dir:
             self.script_root, self.log_root = self._make_export_dir()
             output_file = os.path.join(self.script_root, HTML_FILE)
-            self.static_root = "static/"
+            if not self.static_root.startswith("http"):
+                self.static_root = "static/"
 
         if not record_list:
             record_list = [f for f in os.listdir(self.log_root) if f.endswith(".mp4")]
-        records = [os.path.join(self.log_root, f) for f in record_list]
+        records = [os.path.join(LOGDIR, f) if self.export_dir
+                   else os.path.abspath(os.path.join(self.log_root, f)) for f in record_list]
 
         if not self.static_root.endswith(os.path.sep):
             self.static_root = self.static_root.replace("\\", "/")
@@ -350,8 +369,11 @@ class LogToHtml(object):
         return self._render(template_name, output_file, **data)
 
 
-def simple_report(logpath, tplpath=".", logfile=LOGFILE, output=HTML_FILE):
-    rpt = LogToHtml(tplpath, logpath, logfile=logfile)
+def simple_report(filepath, logpath=True, logfile=LOGFILE, output=HTML_FILE):
+    path, name = script_dir_name(filepath)
+    if logpath is True:
+        logpath = os.path.join(path, LOGDIR)
+    rpt = LogToHtml(path, logpath, logfile=logfile, script_name=name)
     rpt.report(HTML_TPL, output_file=output)
 
 
@@ -364,12 +386,13 @@ def get_parger(ap):
     ap.add_argument("--export", help="export a portable report dir containing all resources")
     ap.add_argument("--lang", help="report language", default="en")
     ap.add_argument("--plugins", help="load reporter plugins", nargs="+")
+    ap.add_argument("--report", help="placeholder for report cmd", default=True, nargs="?")
     return ap
 
 
 def main(args):
     # script filepath
-    path = decode_path(args.script)
+    path, name = script_dir_name(args.script)
     record_list = args.record or []
     log_root = decode_path(args.log_root) or decode_path(os.path.join(path, LOGDIR))
     static_root = args.static_root or STATIC_DIR
@@ -379,7 +402,7 @@ def main(args):
     plugins = args.plugins
 
     # gen html report
-    rpt = LogToHtml(path, log_root, static_root, export_dir=export, lang=lang, plugins=plugins)
+    rpt = LogToHtml(path, log_root, static_root, export_dir=export, script_name=name, lang=lang, plugins=plugins)
     rpt.report(HTML_TPL, output_file=args.outfile, record_list=record_list)
 
 
